@@ -207,6 +207,7 @@ class PoserConst(object):
   # MLS Enhancement. Based on Mean Less Square calc 
   C_MLS_ENHANCEMENT = 2
 
+  # Remove any 'BODY' const strings and replace them by a getRoot() as Figure level
   C_BODY = "BODY"
 
   C_UNIVERSE = "UNIVERSE"
@@ -275,15 +276,6 @@ class PoserConst(object):
   # S_GLOBAL_OBJFILE_PFX = "20 "
   S_LOCAL_OBJFILE_PFX = "0 0 "
   
-  # Characters allowed for numeric float input 
-  #S_NUMDBLCHARS = "0123456789.,+-eE"
-  # Characters allowed for numeric integer input 
-  #S_NUMINTCHARS = "0123456789"
-  # Character used to separate vector values 
-  #S_VECTSEP = ";"
-  # Characters allowed for numeric vector input 
-  #S_NUMVECTCHARS = S_NUMDBLCHARS + S_VECTSEP
-
   C_NO_PARM = "NO_PARM"
   C_NO_NODE = "NO_NODE"
   C_NO_MAPG = '"NO_MAP"'
@@ -582,7 +574,7 @@ class PoserToken:
   E_alternateGeom = PToken("alternateGeom", True, 'AlternateGeom', False)
   E_geomChan = PToken("geomChan", True, 'GenericTransform', False)
   E_clothDynamicsParm = PToken("clothDynamicsParm", True, 'GenericTransform', False)
-  E_channels = PToken("channels", True, 'Channels', False)
+  E_channels = PToken("channels", True, 'StructuredAttribut', False)
   
   E_liteFalloffStart = PToken("liteFalloffStart", True, 'GenericTransform', False)
   E_liteFalloffEnd = PToken("liteFalloffEnd", True, 'GenericTransform', False)
@@ -626,7 +618,7 @@ class PoserToken:
   E_newWinWidth = PToken("newWinWidth", False, None, False)
   E_newWinHeight = PToken("newWinHeight", False, None, False)
   E_newWinDPI = PToken("newWinDPI", False, None, False)
-  E_setGeomHandlerOffset = PToken("setGeomHandlerOffset", False, 'OrientationSA', False)
+  E_setGeomHandlerOffset = PToken("setGeomHandlerOffset", False, None, False)
   
   E_focal = PToken("focal", True, 'GenericTransform', False)
   E_hither = PToken("hither", True, 'GenericTransform', False)
@@ -652,7 +644,7 @@ class PoserToken:
   E_smoothScaleX = PToken("smoothScaleX", True, 'GenericTransform', False)
   E_smoothScaleY = PToken("smoothScaleY", True, 'GenericTransform', False)
   E_smoothScaleZ = PToken("smoothScaleZ", True, 'GenericTransform', False)
-  E_smoothZones = PToken("smoothZones", False, 'ColorSA', False)
+  E_smoothZones = PToken("smoothZones", False, None, False)
   
   E_deltas = PToken("deltas", True, 'Deltas', False)
   E_indexes = PToken("indexes", False)
@@ -695,7 +687,7 @@ class PoserToken:
   E_inkyChain = PToken("inkyChain", True, 'InkyChain', False)
   E_addLink = PToken("addLink", False, None, False)
   E_goal = PToken("goal", False, None, False)
-  E_linkWeight = PToken("linkWeight", False, 'LinkWeightSA', False)
+  E_linkWeight = PToken("linkWeight", False, None, False)
   E_linkParms = PToken("linkParms", False, 'LinkParmsSA', False)
   
   E_defaultPick = PToken("defaultPick", False, None, False)
@@ -722,9 +714,9 @@ class PoserToken:
   E_fastTracking = PToken("fastTracking", False, None, False)
   E_groundShadows = PToken("groundShadows", False, None, False)
   E_bendBodies = PToken("bendBodies", False, None, False)
-  E_fgColor = PToken("fgColor", False, 'OriginSA', False)
-  E_bgColor = PToken("bgColor", False, 'OriginSA', False)
-  E_shadowColor = PToken("shadowColor", False, 'OriginSA', False)
+  E_fgColor = PToken("fgColor", False, None, False)
+  E_bgColor = PToken("bgColor", False, None, False)
+  E_shadowColor = PToken("shadowColor", False, None, False)
   E_paperTexture = PToken("paperTexture", False, None, False)
   E_addActor = PToken("addActor", False, None, False)
   E_pickActor = PToken("pickActor", False, None, False)
@@ -793,13 +785,33 @@ class PoserToken:
   E_pt = PToken("pt", False, None, False)
   E_calcCurve = PToken("calcCurve", False, None, False)
   
+  E_waveDeformerProp = PToken("waveDeformerProp", True, 'WaveDeformerProp', False)
+  E_wavePhase = PToken("wavePhase", True, 'GenericTransform', False)
+  E_waveAmplitude = PToken("waveAmplitude", True, 'GenericTransform', False)
+  E_waveLength = PToken("waveLength", True, 'GenericTransform', False)
+  E_waveStretch = PToken("waveStretch", True, 'GenericTransform', False)
+  E_waveAmplitudeNoise = PToken("waveAmplitudeNoise", True, 'GenericTransform', False)
+  E_waveFrequency = PToken("waveFrequency", True, 'GenericTransform', False)
+  E_waveSinusoidal = PToken("waveSinusoidal", True, 'GenericTransform', False)
+  E_waveRectangular = PToken("waveRectangular", True, 'GenericTransform', False)
+  E_waveTriangular = PToken("waveTriangular", True, 'GenericTransform', False)
+  E_waveTurbulence = PToken("waveTurbulence", True, 'GenericTransform', False)
+  E_waveOffset = PToken("waveOffset", True, 'GenericTransform', False)
+  E_waveType = PToken("waveType", False, None, False)
+
+  E_coneForceFieldProp = PToken("coneForceFieldProp", True, 'ConeForceFieldProp', False)
+  E_forceAmplitude = PToken("forceAmplitude", True, 'GenericTransform', False)
+  E_simpleFloat = PToken("simpleFloat", True, 'GenericTransform', False)
+  E_subType = PToken("subType", False, None, False)
+
+
   E_otherActor = PToken("otherActor", False, None, False)
   E_matrixActor = PToken("matrixActor", False, None, False)
-  E_center = PToken("center", False, 'OriginSA', False)
+  E_center = PToken("center", False, None, False)
   E_startPt = PToken("startPt", False, None, False)
   E_endPt = PToken("endPt", False, None, False)
   E_flipped = PToken("flipped", False) # flipped may be followed by a boolean value.
-  E_angles = PToken("angles", False, 'ColorSA', False)
+  E_angles = PToken("angles", False, None, False)
   E_posBulgeLeft = PToken("posBulgeLeft", False, None, False)
   E_posBulgeRight = PToken("posBulgeRight", False, None, False)
   E_negBulgeLeft = PToken("negBulgeLeft", False, None, False)
@@ -915,7 +927,7 @@ class PoserToken:
   E_lineWidth = PToken("lineWidth", False, None, False)
   E_autoPlay = PToken("autoPlay", False, None, False)
   
-  E_storageOffset = PToken("storageOffset", False, 'StorageOffsetSA', False)
+  E_storageOffset = PToken("storageOffset", False, None, False)
   E_geomHandlerGeom = PToken("geomHandlerGeom", False)
   E_endPoint = PToken("endPoint", False)
   E_origin = PToken("origin", False)
@@ -924,14 +936,14 @@ class PoserToken:
   E_off = PToken("off", False)
   E_sm = PToken("sm", False, 'OffSA', False)
   E_calcWeights = PToken("calcWeights", False, 'OffSA', False)
-  E_KdColor = PToken("KdColor", False, 'ColorSA', False)
-  E_KaColor = PToken("KaColor", False, 'ColorSA', False)
-  E_KsColor = PToken("KsColor", False, 'ColorSA', False)
-  E_ReflectionColor = PToken("ReflectionColor", False, 'ColorSA', False)
-  E_TextureColor = PToken("TextureColor", False, 'ColorSA', False)
+  E_KdColor = PToken("KdColor", False, None, False)
+  E_KaColor = PToken("KaColor", False, None, False)
+  E_KsColor = PToken("KsColor", False, None, False)
+  E_ReflectionColor = PToken("ReflectionColor", False, None, False)
+  E_TextureColor = PToken("TextureColor", False, None, False)
   
-  E_port = PToken("port", False, 'ColorSA', False) # Use a Quad attribut
-  E_d = PToken("d", False, 'ColorSA', False)
+  E_port = PToken("port", False, None, False) # Use a Quad attribut
+  E_d = PToken("d", False, None, False)
   E_readScript = PToken("readScript", False, None, False)
   # Use a Quad attribut   // Use a Quad attribut
   
@@ -952,8 +964,8 @@ class PoserToken:
   E_turbDelay = PToken("turbDelay", False, None, False)
   E_showPopulated = PToken("showPopulated", False, None, False)
   E_doCollisions = PToken("doCollisions", False, None, False)
-  E_widthRange = PToken("widthRange", False, 'HairRange', False)
-  E_lengthRange = PToken("lengthRange", False, 'HairRange', False)
+  E_widthRange = PToken("widthRange", False, None, False)
+  E_lengthRange = PToken("lengthRange", False, None, False)
   E_clumpiness = PToken("clumpiness", False, None, False)
   E_gravityK = PToken("gravityK", False, None, False)
   E_maxRotLenDelta = PToken("maxRotLenDelta", False, None, False)
