@@ -259,7 +259,7 @@ class GeomGroup(object):
     return coordIdx
     
   def addFaceByEdges(self, lstEdges, hasTexture, materialName, refNorm=None):
-    ''' Create the closiing face(s) and add it(them) to the list of faces of the group.
+    ''' Create the closing face(s) and add it(them) to the list of faces of the group.
     This method uses the CreateLoop function based on a min/max tree search with 
     alpha-beta prune. 
 
