@@ -200,6 +200,11 @@ class Point3d(object):
   
   def Z(self): return self.z
 
+  def get(self,i): return self.x if i==0 else self.y if i==1 else self.z
+
+  def __getitem__(self, i):
+    return self.x if i==0 else self.y if i==1 else self.z
+
   def __eq__(self, other):
     ''' Compare two Point3d.
 
@@ -427,6 +432,21 @@ class Point3d(object):
 
   def __sub__(self, other):
     return Point3d(self).sub(other)
+  
+  # Methods added for the decimate algorithm
+  # public static Vec3 triangle_raw_normal(Vec3 v1, Vec3 v2, Vec3 v3)
+  @classmethod
+  def triangle_raw_normal(cls, v1, v2, v3):
+    v21 = Point3d(v2).sub(v1)
+    v31 = Point3d(v3).sub(v1)
+    return v21.cross(v31)
+
+  @classmethod
+  # public static Vec3 triangle_normal(Vec3 v1, Vec3 v2, Vec3 v3)
+  def triangle_normal(cls, v1, v2, v3):
+    n = Point3d.triangle_raw_normal(v1, v2, v3)
+    n.normalize()
+    return n
 
   # End of Class Point3d ======================================================
 
@@ -485,6 +505,22 @@ class TexCoord2f():
         self.y += v[1]
 
     return self
+  
+  def set(self, x=0.0, y=0.0):
+    ''' Fill a TexCoord2f with various inputs.
+    Arguments similar to __init__
+    '''
+    if isinstance(x, TexCoord2f):
+      self.x = x.x 
+      self.y = x.y 
+    elif isinstance(x, float):
+      self.x = x 
+      self.y = y 
+    else: # x is supposed to be a table of 3 floats
+      self.x = x[0]
+      self.y = x[1] 
+
+    return self
 
   def scale(self, scalaire):
     ''' Multiply self by a scalar (float) '''
@@ -531,7 +567,7 @@ class TexCoord2f():
   
   def __le__(self, other):
     return NotImplemented
-
+  
   # End of Class TexCoord2f ====================================================
   
 
